==> kadaster-gds2-2.0-sources.jar: nl/kadaster/schemas/gds2/imgds/baseurl/v20170401/ObjectFactory.java <==

package nl.kadaster.schemas.gds2.imgds.baseurl.v20170401;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the nl.kadaster.schemas.gds2.imgds.baseurl.v20170401 package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _BaseURLSet_QNAME = new QName("http://www.kadaster.nl/schemas/gds2/imgds/baseurl/v20170401", "BaseURLSet");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: nl.kadaster.schemas.gds2.imgds.baseurl.v20170401
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link BaseURLSetType }
     * 
     */
    public BaseURLSetType createBaseURLSetType() {
        return new BaseURLSetType();
    }

    /**
     * Create an instance of {@link BaseURLType }
     * 
     */
    public BaseURLType createBaseURLType() {
        return new BaseURLType();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link BaseURLSetType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link BaseURLSetType }{@code >}
     */
    @XmlElementDecl(namespace = "http://www.kadaster.nl/schemas/gds2/imgds/baseurl/v20170401", name = "BaseURLSet")
    public JAXBElement<BaseURLSetType> createBaseURLSet(BaseURLSetType value) {
        return new JAXBElement<BaseURLSetType>(_BaseURLSet_QNAME, BaseURLSetType.class, null, value);
    }

}

==> kadaster-gds2-2.5-sources.jar: nl/kadaster/schemas/gds2/imgds/baseurl/v20170401/ObjectFactory.java <==

package nl.kadaster.schemas.gds2.imgds.baseurl.v20170401;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the nl.kadaster.schemas.gds2.imgds.baseurl.v20170401 package. 
 * &lt;p&gt;An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _BaseURLSet_QNAME = new QName("http://www.kadaster.nl/schemas/gds2/imgds/baseurl/v20170401", "BaseURLSet");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: nl.kadaster.schemas.gds2.imgds.baseurl.v20170401
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link BaseURLSetType }
     * 
     */
    public BaseURLSetType createBaseURLSetType() {
        return new BaseURLSetType();
    }

    /**
     * Create an instance of {@link BaseURLType }
     * 
     */
    public BaseURLType createBaseURLType() {
        return new BaseURLType();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link BaseURLSetType }{@code >}
     * 
     * @param value
     *     Java instance representing xml element's value.
     * @return
     *     the new instance of {@link JAXBElement }{@code <}{@link BaseURLSetType }{@code >}
     */
    @XmlElementDecl(namespace = "http://www.kadaster.nl/schemas/gds2/imgds/baseurl/v20170401", name = "BaseURLSet")
    public JAXBElement<BaseURLSetType> createBaseURLSet(BaseURLSetType value) {
        return new JAXBElement<BaseURLSetType>(_BaseURLSet_QNAME, BaseURLSetType.class, null, value);
    }

}
